@@ -1,14 +1,13 @@
 import { css } from '@emotion/css';
-import history from 'history';
-import { useEffect, useMemo, useRef, useState } from 'react';
+import React, { useEffect, useMemo, useRef, useState } from 'react';
 import { connect, ConnectedProps } from 'react-redux';
-import { useHistory } from 'react-router-dom';
+import { useLocation, useNavigate, Location } from 'react-router-dom-v5-compat';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { reportInteraction } from '@grafana/runtime';
 import { useStyles2 } from '@grafana/ui';
+import { FormPrompt } from 'app/core/components/FormPrompt/FormPrompt';
 
-import { FormPrompt } from '../../shared/FormPrompt';
 import { Stepper } from '../../shared/Stepper';
 import { EnterpriseStoreState, Report, ReportState, StepKey } from '../../types';
 import { BASE_URL } from '../constants';
@@ -77,7 +76,8 @@ export const ReportForm = ({
 }: Props) => {
   const styles = useStyles2(getStyles);
   const nextStep = getNextStep(activeStep);
-  const history = useHistory();
+  const navigate = useNavigate();
+  const location = useLocation();
 
   const buttonRef = useRef<HTMLButtonElement>(null);
   const [redirect, setRedirect] = useState(false);
@@ -95,15 +95,15 @@ export const ReportForm = ({
 
   useEffect(() => {
     if (redirect) {
-      history.push(BASE_URL);
+      navigate(BASE_URL);
     }
-  }, [redirect, history]);
+  }, [redirect, navigate]);
 
   const onSubmitCustom = (e: React.FormEvent) => {
     e.preventDefault();
     const url = getSectionUrl(nextStep.id, reportId);
     onSubmit();
-    history.push(url);
+    navigate(url);
   };
 
   const saveDraft = async () => {
@@ -133,7 +133,7 @@ export const ReportForm = ({
   };
 
   // Detect navigation outside of form to clear form state if no changes to the form have been made
-  const detectLeavingForm = (location: history.Location) => {
+  const detectLeavingForm = (location: Location) => {
     const reportFormUrls = reportSteps.map((step) => getSectionUrl(step.id, reportId));
     return !reportFormUrls.includes(location.pathname);
   };
@@ -147,15 +147,15 @@ export const ReportForm = ({
   };
 
   const discardChanges = () => {
-    const urlParams = new URLSearchParams(history.location.search);
+    const urlParams = new URLSearchParams(location.search);
     const dashboardUid = urlParams.get('db-uid');
     if (dashboardUid) {
       urlParams.delete('db-uid');
       urlParams.delete('db-name');
 
-      history.push(`/d/${dashboardUid}?${urlParams}`);
+      navigate(`/d/${dashboardUid}?${urlParams}`);
     } else {
-      history.push(BASE_URL);
+      navigate(BASE_URL);
     }
   };
 
@@ -181,6 +181,7 @@ export const ReportForm = ({
       <FormPrompt
         confirmRedirect={!redirect && Boolean(confirmRedirect || isUpdated)}
         onDiscard={onReportDiscarded}
+        //@ts-expect-error TODO: Fix types in FormPrompt
         onLocationChange={detectLeavingForm}
       />
       <div className={styles.inner}>
@@ -205,22 +206,22 @@ export const ReportForm = ({
 
 const getStyles = (theme: GrafanaTheme2) => {
   return {
-    container: css`
-      display: flex;
-      flex-direction: column;
-      height: 100%;
-      align-content: center;
-    `,
-    inner: css`
-      display: flex;
-      justify-content: flex-start;
-      flex-direction: column;
-      flex: 1 0 auto;
-    `,
-    content: css`
-      padding-bottom: ${theme.spacing(3)};
-      width: min(70%, 800px);
-    `,
+    container: css({
+      display: 'flex',
+      flexDirection: 'column',
+      height: '100%',
+      alignContent: 'center',
+    }),
+    inner: css({
+      display: 'flex',
+      justifyContent: 'flex-start',
+      flexDirection: 'column',
+      flex: '1 0 auto',
+    }),
+    content: css({
+      paddingBottom: theme.spacing(3),
+      width: 'min(70%, 800px)',
+    }),
   };
 };
 
